@@ -20,7 +20,7 @@ dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the re
 LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!
 
 translation_copyrights="English, German: George Ruinelli\n"+\
-                                     (u'Français')+": Fred Kwame Ayanfu & Guy Roussin\n"+\
+                                     (u'Français')+": Fred Kwame Ayanful & Guy Roussin\n"+\
                                      "Dutch: Fred Kwame Ayanful\n"+\
                                      "Chinese: "+(u'蒋岚')+" (Peter3316)"
 
