@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 ###########################################################################
-## File:		functions_general.py
+## File:        functions_general.py
 ## Description: This file includes various functions
 ###########################################################################
 
@@ -39,8 +39,8 @@ _ = i18n.language.ugettext
 ###########################################################################
 ## Function:    LoadConfig
 ## Description: This function loads the data from the config file
-##				If the parameter is missing in the config file, it uses
-##				the default value from file data.py
+##                If the parameter is missing in the config file, it uses
+##                the default value from file data.py
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -230,6 +230,11 @@ def LoadConfig():
     except:
         config.set('main', 'WakeUp_Song_Volume', str(data.WakeUp_Song_Volume))
 
+    try:
+        data.WakeUp_Song_Volume_Increase_Step = config.getint('main', 'WakeUp_Song_Volume_Increase_Step')
+    except:
+        config.set('main', 'WakeUp_Song_Volume_Increase_Step', str(data.WakeUp_Song_Volume_Increase_Step))
+
     try:
         data.WakeUp_Song_Duration = config.getint('main', 'WakeUp_Song_Duration')
     except:
@@ -320,7 +325,7 @@ def WriteConfig():
 ###########################################################################
 ## Function:    PrintConfig
 ## Description: This function prints out the current configuration
-##				It is for debugging only
+##                It is for debugging only
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -332,12 +337,12 @@ def PrintConfig():
     print "##########################################################"
 
 
-	
-	
+
+
 ###########################################################################
 ## Function:    Seconds2Tuple
 ## Description: This function converts the integer value of seconds since 1970
-##				into a time tuple
+##                into a time tuple
 ## Parameters:  seconds since 1970
 ## Returns:     time tuple
 ###########################################################################
@@ -346,12 +351,12 @@ def Seconds2Tuple(secs):
     return tuple
 
 
-	
+
 
 ###########################################################################
 ## Function:    Tuple2Seconds
 ## Description: This function converts the time tupple into an integer
-##				of seconds since 1970
+##                of seconds since 1970
 ## Parameters:  time tuple
 ## Returns:     seconds since 1970
 ###########################################################################
@@ -361,11 +366,11 @@ def Tuple2Seconds(Tuple):
 
 
 
-	
+
 ###########################################################################
 ## Function:    Tuple2Index
 ## Description: This function calculates the index in the recod array from
-##				the parameter Tuple, relative to the record start time
+##                the parameter Tuple, relative to the record start time
 ## Parameters:  time Tuple
 ## Returns:     record array index
 ###########################################################################
@@ -377,12 +382,12 @@ def Tuple2Index(Tuple):
 
 
 
-	
-	
+
+
 ###########################################################################
 ## Function:    Index2Tuple
 ## Description: This function calculates the time tuple out of the
-##				parameter Index relative to the record start time
+##                parameter Index relative to the record start time
 ## Parameters:  Index from record array
 ## Returns:     time tuple
 ###########################################################################
@@ -401,7 +406,7 @@ def Index2Tuple(Index):
 ###########################################################################
 ## Function:    SwitchModes
 ## Description: This function switches to offline mode and silence profile
-##				if requested and restores the previos state after the recording
+##                if requested and restores the previos state after the recording
 ## Parameters:  start: True (recording start), False (recording end)
 ## Returns:     none
 ###########################################################################
@@ -509,12 +514,13 @@ def set_silent(silent):
 ## Returns:     none
 ###########################################################################
 def SetVolume(percent):
-    cmd="dbus-send --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.set_extension_property string:volume variant:uint32:"+str(percent)
+    p=int(percent)
+    cmd="dbus-send --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.set_extension_property string:volume variant:uint32:"+str(p)
     os.popen(cmd)
-    data.CurrentVolume=percent
+#    data.CurrentVolume=percent
+
 
 
-	
 
 
 ###########################################################################
@@ -535,8 +541,8 @@ def GetVolume():
 
 
 
-		
-		
+
+
 ###########################################################################
 ## Function:    Notify
 ## Description: Shows a notification message
@@ -549,7 +555,7 @@ def Notify(notify_txt):
 
 
 
-	
+
 ###########################################################################
 ## Function:    PlaySong
 ## Description: Sets the requested volume and opens the media player with the requested song
@@ -566,7 +572,7 @@ def PlaySong(volume, filename):
 
 
 
-	
+
 ###########################################################################
 ## Function:    PauseSong
 ## Description: This function switches the media player to pause
@@ -581,8 +587,8 @@ def PauseSong():
 
 
 
-	
-	
+
+
 ###########################################################################
 ## Function:    GetSongLength
 ## Description: This function returns the duration of a song
@@ -599,8 +605,8 @@ def GetSongLength(filename):
 
 
 
-	
-	
+
+
 ###########################################################################
 ## Function:    CloseMediaPlayer
 ## Description: This function closes the media player
@@ -620,7 +626,7 @@ def CloseMediaPlayer():
 ###########################################################################
 ## Function:    CloseMediaPlayer
 ## Description: This function can measure the time needed for a certain code block
-##				It is only used for debugging
+##                It is only used for debugging
 ## Parameters:  text to be printer, reset time: True/False
 ## Returns:     none
 ############################################################################
