@@ -283,7 +283,7 @@ def DrawGraph(self, QtGui):
                     for k in range(1, 6): #hour + k * 10 minutes
                         x=i+k*decade/6
                         paint.drawLine(x, data.Ysize, x, data.Ysize+10)
-                        paint.drawText(x-20, data.Ysize+26, str(h)+":"+str(10*k))
+                        if(x-20>-5): paint.drawText(x-20, data.Ysize+26, str(h)+":"+str(10*k))
                     for m in range(1, 30): #hour + m * 2 minutes
                         x2=i+m*decade/30
                         paint.drawLine(x2, data.Ysize, x2, data.Ysize+4)
@@ -292,7 +292,7 @@ def DrawGraph(self, QtGui):
                 for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade, decade): #full hours
                     h=(h+1) % 24
                     paint.drawLine(i, data.Ysize, i, data.Ysize+10)
-                    paint.drawText(i-15, data.Ysize+30, str(h)+":00")
+                    if(i-15>-5): paint.drawText(i-15, data.Ysize+30, str(h)+":00")
                     for k in range(1, 6): #hour + k * 10 minutes
                         x=i+k*decade/6
                         paint.drawLine(x, data.Ysize, x, data.Ysize+4)
@@ -345,7 +345,6 @@ def DrawGraph(self, QtGui):
 
         #sleep graph (blue graph)
         pen=QtGui.QPen()
-
         pen.setColor(QtGui.QColor(19, 54, 255, 150))
         pen.setWidth(1)
         paint.setPen(pen)
@@ -436,6 +435,7 @@ def DrawGraph(self, QtGui):
 #                paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
                 x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation*Xscale
                 x00=(x0-GraphStart_index)/Xscale
+                x00=min(x00, data.GraphBitMapLen-40)
                 paint.drawLine(x00, y-17, data.GraphBitMapLen, y-17)  #Trigger line
                 if(y<18):
                     y=33
